(function () {
  const sleep = ms => new Promise(res => setTimeout(res, ms));

  const simulateClick = el => {
    ["pointerdown", "pointerup", "click"].forEach(type => {
      el.dispatchEvent(new PointerEvent(type, {
        bubbles: true,
        cancelable: true,
        composed: true,
        pointerType: "mouse"
      }));
    });
  };

  const findOptionsButton = () => {
    return [...document.querySelectorAll('div[role="button"]')].find(div =>
      div.querySelector('svg[aria-label="Options"]')
    );
  };

  const waitFor = (fn, timeout = 5000) => new Promise((resolve, reject) => {
    const interval = 100;
    let waited = 0;
    const check = () => {
      const result = fn();
      if (result) return resolve(result);
      waited += interval;
      if (waited >= timeout) return reject("Timeout");
      setTimeout(check, interval);
    };
    check();
  });

  const clickBlockInMenu = () => {
    const blockBtn = [...document.querySelectorAll('*')].find(el =>
      el.innerText?.trim().toLowerCase() === 'block' &&
      el.offsetHeight > 0 &&
      getComputedStyle(el).display !== 'none'
    );
    if (blockBtn) {
      console.log("✅ Clicked Block in menu");
      simulateClick(blockBtn);
    } else {
      throw new Error("Block menu item not found");
    }
  };

  const confirmBlock = () => {
    const dialog = document.querySelector('[role="dialog"]');
    if (!dialog) throw new Error("Dialog not found");

    const buttons = [...dialog.querySelectorAll('button')].filter(b =>
      b.innerText.trim().toLowerCase() === 'block' &&
      b.offsetParent !== null
    );

    const confirmBtn = buttons[0];
    if (!confirmBtn) throw new Error("Confirm Block button not found");

    console.log("✅ Clicking confirm block button directly");
    simulateClick(confirmBtn);
  };

  const addBlockBtn = () => {
    const section = document.querySelector('header section');
    if (!section || document.querySelector('#one-click-block-btn')) return;

    const btn = document.createElement('button');
    btn.id = 'one-click-block-btn';
    btn.textContent = '🚫 Block';
    Object.assign(btn.style, {
      marginLeft: '10px',
      padding: '6px 12px',
      background: '#ed4956',
      color: '#fff',
      border: 'none',
      borderRadius: '6px',
      cursor: 'pointer'
    });

    btn.onclick = async () => {
      try {
        console.log("🔸 Clicking ⋯ options");
        const options = findOptionsButton();
        if (!options) throw new Error("Options menu not found");
        simulateClick(options);

        await waitFor(() =>
          [...document.querySelectorAll('*')].some(el =>
            el.innerText?.trim().toLowerCase() === 'block' && el.offsetHeight > 0
          )
        );

        await sleep(300);
        clickBlockInMenu();

        await waitFor(() => document.querySelector('[role="dialog"]'));
        await sleep(500);
        confirmBlock();
      } catch (err) {
        console.error("❌ Block failed:", err);
      }
    };

    section.appendChild(btn);
  };

  const observer = new MutationObserver(() => {
    if (/^\/[^/]+\/$/.test(location.pathname)) {
      addBlockBtn();
    }
  });

  observer.observe(document.body, { childList: true, subtree: true });
})();

